@@ -7,26 +7,43 @@ import cv2
 import numpy as np
 
 from docviz.lib.detection import Detector
-from docviz.lib.document import (
-    analyze_pdf,
-    extract_pdf_page_text,
-    extract_pdf_text_excluding_regions,
+from docviz.lib.extraction.utils import filter_detections
+from docviz.lib.image import ChartSummarizer, extract_regions, fill_regions_with_color
+from docviz.lib.pdf import (
+    # analyze_pdf,
+    # extract_pdf_page_text,
+    # extract_pdf_text_excluding_regions,
     extract_text_from_image,
     pdf_to_png,
 )
-from docviz.lib.extraction.utils import filter_detections
-from docviz.lib.image import ChartSummarizer, extract_regions, fill_regions_with_color
+from docviz.lib.pdf.pdf_analyzer import (
+    analyze_pdf,
+    extract_pdf_page_text,
+    extract_pdf_text_excluding_regions,
+)
 from docviz.logging import get_logger
-from docviz.types import DetectionResult, RectangleTuple, RectangleUnion
+from docviz.types import (
+    DetectionConfig,
+    DetectionResult,
+    ExtractionConfig,
+    ExtractionType,
+    LLMConfig,
+    OCRConfig,
+    RectangleTuple,
+    RectangleUnion,
+)
 
 logger = get_logger(__name__)
 
 
 def pipeline(
-    document_path: str,
-    model_path: str,
-    output_dir: str,
-    page_limit: int | None = None,
+    document_path: Path,
+    output_dir: Path,
+    detection_config: DetectionConfig,
+    extraction_config: ExtractionConfig,
+    ocr_config: OCRConfig,
+    llm_config: LLMConfig,
+    includes: list[ExtractionType],
 ) -> list[dict[str, Any]]:
     """
     Full pipeline: convert PDF to PNG, detect charts, extract text, and summarize.
@@ -42,30 +59,25 @@ def pipeline(
     """
     logger.info("Starting document processing pipeline")
 
-    # TODO: Pass settings through function arguments with correct types instead of using global settings
-    model_name = settings.vision.provider.model
-    base_url = settings.vision.provider.base_url
-    api_key = settings.vision.provider.api_key
+    model_name = llm_config.model
+    base_url = llm_config.base_url
+    api_key = llm_config.api_key
 
     Path(output_dir).mkdir(parents=True, exist_ok=True)
 
-    # Create temporary directory for intermediate data
     with tempfile.TemporaryDirectory() as temp_dir:
         temp_path = Path(temp_dir)
         logger.debug(f"Created temporary directory: {temp_path}")
 
-        # Convert PDF to PNG in temporary directory (needed for image regions and OCR fallback)
         logger.info("Converting PDF to PNG images")
-        # TODO: Pass settings through function arguments with correct types instead of using global settings
         image_paths = pdf_to_png(
-            pdf_path=document_path,
+            pdf_path=str(document_path),
             output_dir=str(temp_path),
-            zoom_x=settings.processing.zoom_factor,
-            zoom_y=settings.processing.zoom_factor,
+            zoom_x=extraction_config.zoom_x,
+            zoom_y=extraction_config.zoom_y,
         )
         logger.info(f"Converted PDF to {len(image_paths)} PNG images")
 
-        # Optionally analyze PDF pages to detect native text and image regions
         logger.info("Analyzing PDF pages for native text and images")
         try:
             page_analyses = analyze_pdf(document_path)
@@ -78,19 +90,15 @@ def pipeline(
 
         # Initialize models
         logger.info("Initializing detection and summarization models")
-        # TODO: Pass settings through function arguments with correct types instead of using global settings
         detector = Detector(
-            backend=settings.layout_detection_backend,
-            model_path=model_path,
-            settings=settings,
+            config=detection_config,
         )
-        # TODO: Pass settings through function arguments with correct types instead of using global settings
         summarizer = ChartSummarizer(
             model_name=model_name,
             base_url=base_url,
             api_key=api_key or "",
-            retries=settings.vision.retries,
-            timeout=settings.vision.timeout,
+            retries=3,
+            timeout=5,
         )
         logger.info("Models initialized successfully")
 
@@ -102,8 +110,10 @@ def pipeline(
                 logger.error(f"Could not load image at {img_path}")
                 raise FileNotFoundError(f"Could not load image at {img_path}")
 
-            if page_limit is not None and idx >= page_limit:
-                logger.info(f"Page limit of {page_limit} reached, stopping processing.")
+            if extraction_config.page_limit is not None and idx >= extraction_config.page_limit:
+                logger.info(
+                    f"Page limit of {extraction_config.page_limit} reached, stopping processing."
+                )
                 break
 
             logger.info(f"Processing page {idx + 1}/{len(image_paths)}")
@@ -112,8 +122,7 @@ def pipeline(
             detections = detector.parse_layout(img)
 
             analysis = page_analyses[idx]
-            # TODO: Pass settings through function arguments with correct types instead of using global settings
-            prefer_pdf_text = settings.processing.prefer_pdf_text
+            prefer_pdf_text = extraction_config.prefer_pdf_text
             fast_text: str | None = None
             if (
                 analysis is not None
@@ -122,9 +131,8 @@ def pipeline(
                 and not analysis.is_full_page_image
             ):
                 # Merge exclusion regions: image regions from analysis + labels_to_exclude regions from detections
-                # TODO: Pass settings through function arguments with correct types instead of using global settings
                 excluded_label_detections = filter_detections(
-                    detections, settings.processing.labels_to_exclude
+                    detections, extraction_config.labels_to_exclude
                 )
                 excluded_bboxes = [
                     (
@@ -147,8 +155,7 @@ def pipeline(
                 else:
                     fast_text = extract_pdf_page_text(document_path, analysis.page_index)
 
-                # TODO: Pass settings through function arguments with correct types instead of using global settings
-                if fast_text and len(fast_text) < settings.processing.pdf_text_threshold_chars:
+                if fast_text and len(fast_text) < extraction_config.pdf_text_threshold_chars:
                     fast_text = None
                     logger.debug(
                         f"Discarded short PDF text below threshold; will use OCR for page {idx + 1}"
@@ -157,15 +164,14 @@ def pipeline(
                     length = 0 if fast_text is None else len(fast_text)
                     logger.info(f"Using PDF-native text for page {idx + 1} (length={length})")
 
-            # TODO: Pass settings through function arguments with correct types instead of using global settings
             page_result = process_single_page(
                 image=img,
                 page_number=idx + 1,
                 detector=detector,
                 summarizer=summarizer,
-                ocr_lang=settings.processing.ocr_lang,
-                charts_labels=settings.filtration.chart_labels,
-                labels_to_exclude_from_ocr=settings.processing.labels_to_exclude,
+                ocr_lang=ocr_config.lang,
+                charts_labels=ocr_config.chart_labels,
+                labels_to_exclude_from_ocr=ocr_config.labels_to_exclude,
                 pre_extracted_text=fast_text,
                 precomputed_detections=detections,
             )
@@ -293,7 +299,7 @@ def process_chart_elements(
             }
         )
 
-    logger.info(f"Successfully processed {len(chart_elements)} chart elements")
+    logger.info(f"Successfully processed {len(chart_elements)} chart element(-s)")
     return chart_elements
 
 
@@ -361,5 +367,5 @@ def process_text_elements(
     else:
         logger.info("No text extracted from processed image")
 
-    logger.info(f"Successfully processed {len(text_elements)} text elements")
+    logger.info(f"Successfully processed {len(text_elements)} text element(-s)")
     return text_elements
